@@ -29,6 +29,7 @@ import static com.google.errorprone.util.ASTHelpers.getStartPosition;
 import static com.google.errorprone.util.ASTHelpers.getType;
 import static com.google.errorprone.util.ASTHelpers.isConsideredFinal;
 import static com.google.errorprone.util.ASTHelpers.isSameType;
+import static com.google.errorprone.util.ASTHelpers.stripParentheses;
 import static java.lang.String.format;
 import static java.util.Arrays.stream;
 
@@ -47,12 +48,17 @@ import com.google.errorprone.matchers.Matchers;
 import com.google.errorprone.suppliers.Supplier;
 import com.google.errorprone.util.ASTHelpers;
 import com.sun.source.tree.BinaryTree;
+import com.sun.source.tree.CaseTree;
 import com.sun.source.tree.ClassTree;
 import com.sun.source.tree.CompilationUnitTree;
+import com.sun.source.tree.ExpressionStatementTree;
 import com.sun.source.tree.ExpressionTree;
+import com.sun.source.tree.IdentifierTree;
 import com.sun.source.tree.MethodInvocationTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.ParenthesizedTree;
+import com.sun.source.tree.SwitchExpressionTree;
+import com.sun.source.tree.SwitchTree;
 import com.sun.source.tree.Tree;
 import com.sun.source.tree.Tree.Kind;
 import com.sun.source.tree.TypeCastTree;
@@ -64,6 +70,7 @@ import com.sun.tools.javac.code.Symbol.MethodSymbol;
 import com.sun.tools.javac.code.Type;
 import com.sun.tools.javac.tree.JCTree.JCFieldAccess;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
@@ -211,6 +218,34 @@ public final class ImpossibleNullComparison extends BugChecker
           }.visit(tree, null));
     }
 
+    @Override
+    public Void visitSwitch(SwitchTree tree, Void unused) {
+      handleSwitch(tree.getExpression(), tree.getCases());
+      return super.visitSwitch(tree, null);
+    }
+
+    @Override
+    public Void visitSwitchExpression(SwitchExpressionTree tree, Void unused) {
+      handleSwitch(tree.getExpression(), tree.getCases());
+      return super.visitSwitchExpression(tree, null);
+    }
+
+    private void handleSwitch(ExpressionTree expression, List<? extends CaseTree> cases) {
+      var withoutParens = stripParentheses(expression);
+      VisitorState subState = state.withPath(getCurrentPath());
+      for (var caseTree : cases) {
+        caseTree.getExpressions().stream()
+            .filter(e -> isNull(e))
+            .findFirst()
+            // We're not using the fixer, just using it to see if there's a problem.
+            .filter(unused -> getFixer(withoutParens, subState).isPresent())
+            .ifPresent(
+                e ->
+                    // NOTE: This fix is possibly too big: you can write `case null, default ->`.
+                    state.reportMatch(describeMatch(caseTree, SuggestedFix.delete(caseTree))));
+      }
+    }
+
     @Override
     public Void visitBinary(BinaryTree binary, Void unused) {
       if (!COMPARISON_OPERATORS.contains(binary.getKind())) {
@@ -271,7 +306,7 @@ public final class ImpossibleNullComparison extends BugChecker
     }
 
     private @Nullable ExpressionTree getEffectiveTree(ExpressionTree tree) {
-      return tree.getKind() == Kind.IDENTIFIER
+      return tree instanceof IdentifierTree
           ? effectivelyFinalValues.getOrDefault(ASTHelpers.getSymbol(tree), tree)
           : tree;
     }
@@ -413,10 +448,9 @@ public final class ImpossibleNullComparison extends BugChecker
         if (!PROTO_RECEIVER.matches(tree, state)) {
           return null;
         }
-        if (tree.getKind() != Kind.METHOD_INVOCATION) {
+        if (!(tree instanceof MethodInvocationTree method)) {
           return null;
         }
-        MethodInvocationTree method = (MethodInvocationTree) tree;
         if (!method.getArguments().isEmpty()) {
           return null;
         }
@@ -461,10 +495,9 @@ public final class ImpossibleNullComparison extends BugChecker
         if (!PROTO_RECEIVER.matches(tree, state)) {
           return null;
         }
-        if (tree.getKind() != Kind.METHOD_INVOCATION) {
+        if (!(tree instanceof MethodInvocationTree method)) {
           return null;
         }
-        MethodInvocationTree method = (MethodInvocationTree) tree;
         if (method.getArguments().size() != 1 || !isGetter(method.getMethodSelect())) {
           return null;
         }
@@ -494,10 +527,9 @@ public final class ImpossibleNullComparison extends BugChecker
         if (!PROTO_RECEIVER.matches(tree, state)) {
           return null;
         }
-        if (tree.getKind() != Kind.METHOD_INVOCATION) {
+        if (!(tree instanceof MethodInvocationTree method)) {
           return null;
         }
-        MethodInvocationTree method = (MethodInvocationTree) tree;
         if (!method.getArguments().isEmpty()) {
           return null;
         }
@@ -575,10 +607,9 @@ public final class ImpossibleNullComparison extends BugChecker
     }
 
     private static boolean isGetter(ExpressionTree expressionTree) {
-      if (!(expressionTree instanceof JCFieldAccess)) {
+      if (!(expressionTree instanceof JCFieldAccess access)) {
         return false;
       }
-      JCFieldAccess access = (JCFieldAccess) expressionTree;
       String methodName = access.sym.getQualifiedName().toString();
       return methodName.startsWith("get");
     }
@@ -637,7 +668,7 @@ public final class ImpossibleNullComparison extends BugChecker
       SuggestedFix fix(Fixer fixer, ExpressionTree tree, VisitorState state) {
         MethodInvocationTree methodInvocationTree = (MethodInvocationTree) tree;
         Tree parent = state.getPath().getParentPath().getLeaf();
-        return parent.getKind() == Kind.EXPRESSION_STATEMENT
+        return parent instanceof ExpressionStatementTree
             ? SuggestedFix.delete(parent)
             : SuggestedFix.replace(
                 tree, state.getSourceForNode(methodInvocationTree.getArguments().get(0)));
