@@ -640,7 +640,7 @@ public class TruthIncompatibleTypeTest {
     compilationHelper
         .addSourceLines(
             "Test.java",
-            """
+"""
 import static com.google.common.truth.extensions.proto.ProtoTruth.assertThat;
 import com.google.common.collect.ImmutableList;
 import com.google.common.truth.Correspondence;
@@ -695,6 +695,43 @@ public class Test {
         .doTest();
   }
 
+  @Test
+  public void multiset_hasCount_match() {
+    compilationHelper
+        .addSourceLines(
+            "Test.java",
+            """
+            import static com.google.common.truth.Truth.assertThat;
+            import com.google.common.collect.Multiset;
+
+            public class Test {
+              public void f(Multiset<String> a, String b) {
+                assertThat(a).hasCount(b, 1);
+              }
+            }
+            """)
+        .doTest();
+  }
+
+  @Test
+  public void multiset_hasCount_mismatch() {
+    compilationHelper
+        .addSourceLines(
+            "Test.java",
+            """
+            import static com.google.common.truth.Truth.assertThat;
+            import com.google.common.collect.Multiset;
+
+            public class Test {
+              public void f(Multiset<String> a, Long b) {
+                // BUG: Diagnostic contains:
+                assertThat(a).hasCount(b, 1);
+              }
+            }
+            """)
+        .doTest();
+  }
+
   @Test
   public void subjectExhaustiveness(
       @TestParameter(valuesProvider = SubjectMethods.class) Method method) {
